# Changelog

## 0.2.1 (2026-02-25)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/axioradev/axiora-sdk/compare/v0.2.0...v0.2.1)

### Chores

* **internal:** make `test_proxy_environment_variables` more resilient to env ([9fcbdd7](https://github.com/axioradev/axiora-sdk/commit/9fcbdd703ac269e87ca130856b330f9fcd2da43f))

## 0.2.0 (2026-02-25)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/axioradev/axiora-sdk/compare/v0.1.0...v0.2.0)

### Features

* **api:** manual updates ([8352e0d](https://github.com/axioradev/axiora-sdk/commit/8352e0d5681790bb33bcf322a810064b025f1fe7))

## 0.1.0 (2026-02-25)

Full Changelog: [v0.0.3...v0.1.0](https://github.com/axioradev/axiora-sdk/compare/v0.0.3...v0.1.0)

### Features

* **api:** manual updates ([ac38e70](https://github.com/axioradev/axiora-sdk/commit/ac38e7077476c9684d23fcc587f6a8440d701f28))

## 0.0.3 (2026-02-24)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/axioradev/axiora-sdk/compare/v0.0.2...v0.0.3)

### Chores

* update SDK settings ([cee414e](https://github.com/axioradev/axiora-sdk/commit/cee414ecf848b71dc1e5c4f74ad57a79868e8834))
* update SDK settings ([4d1ea9f](https://github.com/axioradev/axiora-sdk/commit/4d1ea9f2f2c067852d4b4db689a8f093dd033181))

## 0.0.2 (2026-02-24)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/axioradev/axiora-sdk/compare/v0.0.1...v0.0.2)

### Chores

* sync repo ([0304381](https://github.com/axioradev/axiora-sdk/commit/03043810581737b145fc39626ab1509527e4d34b))
* update SDK settings ([622f5f7](https://github.com/axioradev/axiora-sdk/commit/622f5f74f3a67500dd0437d41a36afca747a2d80))
* update SDK settings ([6c69d33](https://github.com/axioradev/axiora-sdk/commit/6c69d3300bf11f367b6080fdeee788bbbfe6866e))
* update SDK settings ([6a915cc](https://github.com/axioradev/axiora-sdk/commit/6a915ccae58b24cbd4f29f447b5604bc0e165cb2))
* update SDK settings ([81f7667](https://github.com/axioradev/axiora-sdk/commit/81f766736bec0ae015f1f3331ade01a4de2b87bf))
* update SDK settings ([a6510c8](https://github.com/axioradev/axiora-sdk/commit/a6510c8153050aebc7ec1d99cae089d64d33755b))
* update SDK settings ([0124007](https://github.com/axioradev/axiora-sdk/commit/0124007014e77792fea11e92e510a6f5078a7584))
* update SDK settings ([db38a9e](https://github.com/axioradev/axiora-sdk/commit/db38a9ead622087522dc18634d99475b774a5565))
